@@ -81,6 +81,13 @@ import qualified Data.ByteString.Unsafe   as S
 import qualified Data.ByteString.Base     as S
 #endif
 
+-- From ghc-7.8 (base-4.7.0.0), unsafePerformIO
+-- must be imported from System.IO.Unsafe, since
+-- its removal from Foreign.
+#if __GLASGOW_HASKELL__ >= 708
+import System.IO.Unsafe (unsafePerformIO)
+#endif
+
 -- Foreigns
 import Foreign
 import Foreign.Ptr
